@@ -27,6 +27,7 @@ from repoman.copyrights import update_copyright
 from repoman.gpg import gpgsign, need_signature
 from repoman import utilities
 from repoman.modules.vcs.vcs import vcs_files_to_cps
+from repoman import VERSION
 
 bad = create_color_func("BAD")
 
@@ -108,6 +109,9 @@ class Actions(object):
 						" --commitmsgfile='%s'\n" % self.options.commitmsgfile)
 				else:
 					raise
+			if commitmessage[:9].lower() in ("cat/pkg: ",):
+				commitmessage = self.msg_prefix() + commitmessage[9:]
+
 		if not commitmessage or not commitmessage.strip():
 			commitmessage = self.get_new_commit_message(qa_output)
 
@@ -333,7 +337,8 @@ class Actions(object):
 			portage_version = "Unknown"
 		# Use new footer only for git (see bug #438364).
 		if self.vcs_settings.vcs in ["git"]:
-			commit_footer = "\n\nPackage-Manager: portage-%s" % portage_version
+			commit_footer = "\n\nPackage-Manager: Portage-%s, Repoman-%s" % (
+							portage.VERSION, VERSION)
 			if report_options:
 				commit_footer += "\nRepoMan-Options: " + " ".join(report_options)
 			if self.repo_settings.sign_manifests:
@@ -516,12 +521,14 @@ class Actions(object):
 			portage.writemsg("!!! Disabled FEATURES='sign'\n")
 			self.repo_settings.sign_manifests = False
 
+	def msg_prefix(self):
+		prefix = ""
+		if self.scanner.repolevel > 1:
+			prefix = "/".join(self.scanner.reposplit[1:]) + ": "
+		return prefix
 
 	def get_new_commit_message(self, qa_output):
-		msg_prefix = ""
-		if self.scanner.repolevel > 1:
-			msg_prefix = "/".join(self.scanner.reposplit[1:]) + ": "
-
+		msg_prefix = self.msg_prefix()
 		try:
 			editor = os.environ.get("EDITOR")
 			if editor and utilities.editor_is_executable(editor):
